@@ -1,8 +1,9 @@
 use super::super::super::DbMapKeyType;
 use super::super::{FileBufSizeParam, FileDbParams};
+use super::piece::PieceMgr;
 use super::semtype::*;
 use super::vfile::VarFile;
-use rabuf::SmallRead;
+use rabuf::{SmallRead, SmallWrite};
 use std::cell::RefCell;
 use std::convert::TryInto;
 use std::fs::OpenOptions;
@@ -13,7 +14,8 @@ use std::rc::Rc;
 type HeaderSignature = [u8; 8];
 
 //const CHUNK_SIZE: u32 = 4 * 1024;
-const CHUNK_SIZE: u32 = 4 * 4 * 1024;
+//const CHUNK_SIZE: u32 = 4 * 4 * 1024;
+const CHUNK_SIZE: u32 = 4 * 4 * 4 * 1024;
 const _DAT_HEADER_SZ: u64 = 192;
 const DAT_HEADER_SIGNATURE: HeaderSignature = [b's', b'i', b'a', b'm', b'd', b'b', b'K', 0u8];
 
@@ -32,6 +34,7 @@ impl<KT: DbMapKeyType> KeyFile<KT> {
         sig2: HeaderSignature,
         params: &FileDbParams,
     ) -> Result<Self> {
+        let piece_mgr = PieceMgr::new(&REC_SIZE_FREE_OFFSET, &REC_SIZE_ARY);
         let mut pb = path.as_ref().to_path_buf();
         pb.push(format!("{}.key", ks_name));
         let std_file = OpenOptions::new()
@@ -44,31 +47,23 @@ impl<KT: DbMapKeyType> KeyFile<KT> {
                 let dat_buf_chunk_size = CHUNK_SIZE;
                 let dat_buf_num_chunks = val / dat_buf_chunk_size;
                 VarFile::with_capacity(
-                    &REC_SIZE_FREE_OFFSET,
-                    &REC_SIZE_ARY,
+                    piece_mgr,
                     "key",
                     std_file,
                     dat_buf_chunk_size,
                     dat_buf_num_chunks.try_into().unwrap(),
                 )?
             }
-            FileBufSizeParam::PerMille(val) => VarFile::with_per_mille(
-                &REC_SIZE_FREE_OFFSET,
-                &REC_SIZE_ARY,
-                "key",
-                std_file,
-                CHUNK_SIZE,
-                val,
-            )?,
-            FileBufSizeParam::Auto => {
-                VarFile::new(&REC_SIZE_FREE_OFFSET, &REC_SIZE_ARY, "key", std_file)?
+            FileBufSizeParam::PerMille(val) => {
+                VarFile::with_per_mille(piece_mgr, "key", std_file, CHUNK_SIZE, val)?
             }
+            FileBufSizeParam::Auto => VarFile::new(piece_mgr, "key", std_file)?,
         };
-        let file_length: KeyRecordOffset = file.seek_to_end()?;
+        let file_length: KeyPieceOffset = file.seek_to_end()?;
         if file_length.is_zero() {
-            file.write_keyrecf_init_header(sig2)?;
+            write_keyrecf_init_header(&mut file, sig2)?;
         } else {
-            file.check_keyrecf_header(sig2)?;
+            check_keyrecf_header(&mut file, sig2)?;
         }
         //
         let file_rc = VarFileKeyCache(file, PhantomData);
@@ -103,66 +98,59 @@ impl<KT: DbMapKeyType> KeyFile<KT> {
     }
     //
     #[inline]
-    pub(crate) fn read_record_only_size(&self, offset: KeyRecordOffset) -> Result<KeyRecordSize> {
+    pub(crate) fn read_piece_only_size(&self, offset: KeyPieceOffset) -> Result<KeyPieceSize> {
         let mut locked = self.0.borrow_mut();
-        locked.read_record_only_size(offset)
+        locked.read_piece_only_size(offset)
     }
     #[inline]
-    pub fn read_record_only_key_length(&self, offset: KeyRecordOffset) -> Result<KeyLength> {
+    pub fn read_piece_only_key_length(&self, offset: KeyPieceOffset) -> Result<KeyLength> {
         let mut locked = self.0.borrow_mut();
-        locked.read_record_only_key_length(offset)
+        locked.read_piece_only_key_length(offset)
     }
     #[inline]
-    pub fn read_record_only_key(&self, offset: KeyRecordOffset) -> Result<KT> {
+    pub fn read_piece_only_key(&self, offset: KeyPieceOffset) -> Result<KT> {
         let mut locked = self.0.borrow_mut();
-        locked.read_record_only_key(offset)
+        locked.read_piece_only_key(offset)
     }
     #[inline]
-    pub fn read_record_only_value_offset(
-        &self,
-        offset: KeyRecordOffset,
-    ) -> Result<ValueRecordOffset> {
+    pub fn read_piece_only_value_offset(&self, offset: KeyPieceOffset) -> Result<ValuePieceOffset> {
         let mut locked = self.0.borrow_mut();
-        locked.read_record_only_value_offset(offset)
+        locked.read_piece_only_value_offset(offset)
     }
     #[inline]
-    pub fn read_record(&self, offset: KeyRecordOffset) -> Result<KeyRecord<KT>> {
+    pub fn read_piece(&self, offset: KeyPieceOffset) -> Result<KeyPiece<KT>> {
         let mut locked = self.0.borrow_mut();
-        locked.read_record(offset)
+        locked.read_piece(offset)
     }
     #[inline]
-    pub fn write_record(&self, record: KeyRecord<KT>) -> Result<KeyRecord<KT>> {
+    pub fn write_piece(&self, piece: KeyPiece<KT>) -> Result<KeyPiece<KT>> {
         let mut locked = self.0.borrow_mut();
-        locked.write_record(record, false)
+        locked.write_piece(piece, false)
     }
     #[inline]
-    pub fn delete_record(&self, offset: KeyRecordOffset) -> Result<KeyRecordSize> {
+    pub fn delete_piece(&self, offset: KeyPieceOffset) -> Result<KeyPieceSize> {
         let mut locked = self.0.borrow_mut();
-        locked.delete_record(offset)
+        locked.delete_piece(offset)
     }
     #[inline]
-    pub fn add_key_record(
-        &self,
-        key: &KT,
-        value_offset: ValueRecordOffset,
-    ) -> Result<KeyRecord<KT>> {
+    pub fn add_key_piece(&self, key: &KT, value_offset: ValuePieceOffset) -> Result<KeyPiece<KT>> {
         let mut locked = self.0.borrow_mut();
-        locked.add_key_record(key, value_offset)
+        locked.add_key_piece(key, value_offset)
     }
 }
 
 // for debug
 impl<KT: DbMapKeyType> KeyFile<KT> {
-    pub fn count_of_free_key_record(&self) -> Result<Vec<(u32, u64)>> {
+    pub fn count_of_free_key_piece(&self) -> Result<Vec<(u32, u64)>> {
         let sz_ary = REC_SIZE_ARY;
         //
         let mut vec = Vec::new();
         let mut locked = self.0.borrow_mut();
-        for record_size in sz_ary {
+        for piece_size in sz_ary {
             let cnt = locked
                 .0
-                .count_of_free_piece_list(KeyRecordSize::new(record_size))?;
-            vec.push((record_size, cnt));
+                .count_of_free_piece_list(KeyPieceSize::new(piece_size))?;
+            vec.push((piece_size, cnt));
         }
         Ok(vec)
     }
@@ -195,42 +183,41 @@ The db data header size is 192 bytes.
 
 */
 
-impl VarFile {
-    fn write_keyrecf_init_header(&mut self, signature2: HeaderSignature) -> Result<()> {
-        self.seek_from_start(KeyRecordOffset::new(0))?;
-        // signature1
-        self.write_all(&DAT_HEADER_SIGNATURE)?;
-        // signature2
-        self.write_all(&signature2)?;
-        // reserve0
-        self.write_u64_le(0)?;
-        // reserve1
-        self.write_u64_le(0)?;
-        // free1 .. reserve2
-        self.write_all(&[0u8; 160])?;
-        //
-        Ok(())
-    }
-    fn check_keyrecf_header(&mut self, signature2: HeaderSignature) -> Result<()> {
-        self.seek_from_start(KeyRecordOffset::new(0))?;
-        // signature1
-        let mut sig1 = [0u8, 0u8, 0u8, 0u8, 0u8, 0u8, 0u8, 0u8];
-        let _sz = self.read_exact(&mut sig1)?;
-        assert!(sig1 == DAT_HEADER_SIGNATURE, "invalid header signature1");
-        // signature2
-        let mut sig2 = [0u8, 0u8, 0u8, 0u8, 0u8, 0u8, 0u8, 0u8];
-        let _sz = self.read_exact(&mut sig2)?;
-        assert!(
-            sig2 == signature2,
-            "invalid header signature2, type signature: {:?}",
-            sig2
-        );
-        // reserve0
-        let _reserve0 = self.read_u64_le()?;
-        assert!(_reserve0 == 0, "invalid reserve0");
-        //
-        Ok(())
-    }
+fn write_keyrecf_init_header(file: &mut VarFile, signature2: HeaderSignature) -> Result<()> {
+    file.seek_from_start(KeyPieceOffset::new(0))?;
+    // signature1
+    file.write_all(&DAT_HEADER_SIGNATURE)?;
+    // signature2
+    file.write_all(&signature2)?;
+    // reserve0
+    file.write_u64_le(0)?;
+    // reserve1
+    file.write_u64_le(0)?;
+    // free1 .. reserve2
+    file.write_all(&[0u8; 160])?;
+    //
+    Ok(())
+}
+
+fn check_keyrecf_header(file: &mut VarFile, signature2: HeaderSignature) -> Result<()> {
+    file.seek_from_start(KeyPieceOffset::new(0))?;
+    // signature1
+    let mut sig1 = [0u8, 0u8, 0u8, 0u8, 0u8, 0u8, 0u8, 0u8];
+    let _sz = file.read_exact(&mut sig1)?;
+    assert!(sig1 == DAT_HEADER_SIGNATURE, "invalid header signature1");
+    // signature2
+    let mut sig2 = [0u8, 0u8, 0u8, 0u8, 0u8, 0u8, 0u8, 0u8];
+    let _sz = file.read_exact(&mut sig2)?;
+    assert!(
+        sig2 == signature2,
+        "invalid header signature2, type signature: {:?}",
+        sig2
+    );
+    // reserve0
+    let _reserve0 = file.read_u64_le()?;
+    assert!(_reserve0 == 0, "invalid reserve0");
+    //
+    Ok(())
 }
 
 const REC_SIZE_FREE_OFFSET_1ST: u64 = 32;
@@ -274,19 +261,19 @@ pub(crate) const REC_SIZE_ARY: [u32; 16] = [
 ];
 //    [8 * 2, 8 * 3, 8 * 4, 8 * 6, 8 * 8, 8 * 32, 8 * 64, 8 * 256];
 
-impl KeyRecordSize {
+impl KeyPieceSize {
     pub(crate) fn is_valid_key(&self) -> bool {
-        let record_size = self.as_value();
-        assert!(record_size > 0, "record_size: {} > 0", record_size);
+        let piece_size = self.as_value();
+        assert!(piece_size > 0, "piece_size: {} > 0", piece_size);
         for &sz in &REC_SIZE_ARY {
-            if sz == record_size {
+            if sz == piece_size {
                 return true;
             }
         }
         assert!(
-            record_size > REC_SIZE_ARY[REC_SIZE_ARY.len() - 2],
-            "record_size: {} > REC_SIZE_ARY[REC_SIZE_ARY.len() - 2]: {}",
-            record_size,
+            piece_size > REC_SIZE_ARY[REC_SIZE_ARY.len() - 2],
+            "piece_size: {} > REC_SIZE_ARY[REC_SIZE_ARY.len() - 2]: {}",
+            piece_size,
             REC_SIZE_ARY[REC_SIZE_ARY.len() - 2]
         );
         true
@@ -294,24 +281,24 @@ impl KeyRecordSize {
 }
 
 #[derive(Debug, Default, Clone)]
-pub struct KeyRecord<KT: DbMapKeyType> {
-    /// offset of IdxNode in dat file.
-    pub offset: KeyRecordOffset,
-    /// size in bytes of KeyRecord in dat file.
-    pub size: KeyRecordSize,
+pub struct KeyPiece<KT: DbMapKeyType> {
+    /// offset of KeyPiece in key-file.
+    pub offset: KeyPieceOffset,
+    /// size in bytes of KeyPiece in key-file.
+    pub size: KeyPieceSize,
     /// key data.
     pub key: KT,
     /// value offset.
-    pub value_offset: ValueRecordOffset,
+    pub value_offset: ValuePieceOffset,
 }
 
-impl<KT: DbMapKeyType> KeyRecord<KT> {
+impl<KT: DbMapKeyType> KeyPiece<KT> {
     #[inline]
     pub fn with(
-        offset: KeyRecordOffset,
-        size: KeyRecordSize,
+        offset: KeyPieceOffset,
+        size: KeyPieceSize,
         key: KT,
-        value_offset: ValueRecordOffset,
+        value_offset: ValuePieceOffset,
     ) -> Self {
         Self {
             offset,
@@ -321,7 +308,7 @@ impl<KT: DbMapKeyType> KeyRecord<KT> {
         }
     }
     #[inline]
-    pub fn with_key_value(key: KT, value_offset: ValueRecordOffset) -> Self {
+    pub fn with_key_value(key: KT, value_offset: ValuePieceOffset) -> Self {
         Self {
             key,
             value_offset,
@@ -333,50 +320,50 @@ impl<KT: DbMapKeyType> KeyRecord<KT> {
         self.key.hash_value()
     }
     //
-    fn encoded_record_size(&self) -> (u32, u32, KeyLength) {
+    fn encoded_piece_size(&self) -> (u32, u32, KeyLength) {
         let key = self.key.as_bytes();
         let key_len = KeyLength::new(key.len().try_into().unwrap());
         //
         #[cfg(any(feature = "vf_u32u32", feature = "vf_u64u64"))]
-        let (encorded_record_len, record_len) = {
+        let (encorded_piece_len, piece_len) = {
             let enc_key_len = 4;
             #[cfg(feature = "vf_u32u32")]
             let enc_val_off = 4;
             #[cfg(feature = "vf_u64u64")]
             let enc_val_off = 8;
-            let record_len: u32 = enc_key_len + key_len.as_value() + enc_val_off;
-            let encorded_record_len = 4;
-            (encorded_record_len, record_len)
+            let piece_len: u32 = enc_key_len + key_len.as_value() + enc_val_off;
+            let encorded_piece_len = 4;
+            (encorded_piece_len, piece_len)
         };
         #[cfg(feature = "vf_vu64")]
-        let (encorded_record_len, record_len) = {
+        let (encorded_piece_len, piece_len) = {
             let enc_key_len = vu64::encoded_len(key_len.as_value() as u64) as u32;
             #[cfg(feature = "htx")]
             let enc_val_off = 8;
             #[cfg(not(feature = "htx"))]
             let enc_val_off = vu64::encoded_len(self.value_offset.as_value() as u64) as u32;
-            let record_len: u32 = enc_key_len + key_len.as_value() + enc_val_off;
-            let encorded_record_len = vu64::encoded_len((record_len as u64 + 7) / 8) as u32;
-            (encorded_record_len, record_len)
+            let piece_len: u32 = enc_key_len + key_len.as_value() + enc_val_off;
+            let encorded_piece_len = vu64::encoded_len((piece_len as u64 + 7) / 8) as u32;
+            (encorded_piece_len, piece_len)
         };
         //
-        (encorded_record_len, record_len, key_len)
+        (encorded_piece_len, piece_len, key_len)
     }
     //
-    pub(crate) fn dat_write_record_one(&self, file: &mut VarFile) -> Result<()> {
+    pub(crate) fn dat_write_piece_one(&self, file: &mut VarFile) -> Result<()> {
         assert!(!self.size.is_zero());
         //
         let key = self.key.as_bytes();
         let key_len = KeyLength::new(key.len().try_into().unwrap());
         //
         file.seek_from_start(self.offset)?;
-        file.write_record_size(self.size)?;
+        file.write_piece_size(self.size)?;
         file.write_key_len(key_len)?;
         file.write_all(key)?;
         #[cfg(feature = "htx")]
-        file.write_value_record_offset(self.value_offset)?;
+        file.write_value_piece_offset(self.value_offset)?;
         #[cfg(not(feature = "htx"))]
-        file.write_record_offset(self.value_offset)?;
+        file.write_piece_offset(self.value_offset)?;
         file.write_zero_to_offset(self.offset + self.size)?;
         //
         Ok(())
@@ -384,154 +371,146 @@ impl<KT: DbMapKeyType> KeyRecord<KT> {
 }
 
 impl<KT: DbMapKeyType> VarFileKeyCache<KT> {
-    fn delete_record(&mut self, offset: KeyRecordOffset) -> Result<KeyRecordSize> {
-        let old_record_size = {
+    fn delete_piece(&mut self, offset: KeyPieceOffset) -> Result<KeyPieceSize> {
+        let old_piece_size = {
             self.0.seek_from_start(offset)?;
-            self.0.read_record_size()?
+            self.0.read_piece_size()?
         };
         //
-        self.0.push_free_piece_list(offset, old_record_size)?;
-        Ok(old_record_size)
+        self.0.push_free_piece_list(offset, old_piece_size)?;
+        Ok(old_piece_size)
     }
 
     #[inline]
-    fn add_key_record(
-        &mut self,
-        key: &KT,
-        value_offset: ValueRecordOffset,
-    ) -> Result<KeyRecord<KT>> {
-        self.write_record(KeyRecord::with_key_value(key.clone(), value_offset), true)
+    fn add_key_piece(&mut self, key: &KT, value_offset: ValuePieceOffset) -> Result<KeyPiece<KT>> {
+        self.write_piece(KeyPiece::with_key_value(key.clone(), value_offset), true)
     }
-    fn write_record(&mut self, mut record: KeyRecord<KT>, is_new: bool) -> Result<KeyRecord<KT>> {
-        debug_assert!(is_new || !record.offset.is_zero());
+    fn write_piece(&mut self, mut piece: KeyPiece<KT>, is_new: bool) -> Result<KeyPiece<KT>> {
+        debug_assert!(is_new || !piece.offset.is_zero());
         //
-        let (encorded_record_len, record_len, _key_len) = record.encoded_record_size();
-        let new_record_size = self
+        let (encorded_piece_len, piece_len, _key_len) = piece.encoded_piece_size();
+        let new_piece_size = self
             .0
             .piece_mgr
-            .roundup(KeyRecordSize::new(encorded_record_len + record_len));
+            .roundup(KeyPieceSize::new(encorded_piece_len + piece_len));
         //
         if !is_new {
-            let old_record_size = {
-                self.0.seek_from_start(record.offset)?;
-                self.0.read_record_size()?
+            let old_piece_size = {
+                self.0.seek_from_start(piece.offset)?;
+                self.0.read_piece_size()?
             };
-            debug_assert!(old_record_size.is_valid_key());
-            if new_record_size <= old_record_size {
+            debug_assert!(old_piece_size.is_valid_key());
+            if new_piece_size <= old_piece_size {
                 // over writes.
-                self.0.seek_from_start(record.offset)?;
-                record.size = old_record_size;
-                record.dat_write_record_one(&mut self.0)?;
-                return Ok(record);
+                self.0.seek_from_start(piece.offset)?;
+                piece.size = old_piece_size;
+                piece.dat_write_piece_one(&mut self.0)?;
+                return Ok(piece);
             } else {
                 // delete old and add new
                 // old
-                self.0
-                    .push_free_piece_list(record.offset, old_record_size)?;
+                self.0.push_free_piece_list(piece.offset, old_piece_size)?;
             }
         }
         // add new.
         {
-            let free_record_offset = self.0.pop_free_piece_list(new_record_size)?;
-            let new_record_offset = if !free_record_offset.is_zero() {
-                self.0.seek_from_start(free_record_offset)?;
-                free_record_offset
+            let free_piece_offset = self.0.pop_free_piece_list(new_piece_size)?;
+            let new_piece_offset = if !free_piece_offset.is_zero() {
+                self.0.seek_from_start(free_piece_offset)?;
+                free_piece_offset
             } else {
                 self.0.seek_to_end()?
             };
-            record.offset = new_record_offset;
-            record.size = new_record_size;
-            debug_assert!(record.size.is_valid_key());
-            match record.dat_write_record_one(&mut self.0) {
+            piece.offset = new_piece_offset;
+            piece.size = new_piece_size;
+            debug_assert!(piece.size.is_valid_key());
+            match piece.dat_write_piece_one(&mut self.0) {
                 Ok(()) => (),
                 Err(err) => {
                     // recover on error
-                    let _ = self.0.set_file_length(new_record_offset);
+                    let _ = self.0.set_file_length(new_piece_offset);
                     return Err(err);
                 }
             }
-            record.offset = new_record_offset;
+            piece.offset = new_piece_offset;
         }
         //
-        Ok(record)
+        Ok(piece)
     }
 
-    fn read_record(&mut self, offset: KeyRecordOffset) -> Result<KeyRecord<KT>> {
+    fn read_piece(&mut self, offset: KeyPieceOffset) -> Result<KeyPiece<KT>> {
         debug_assert!(!offset.is_zero());
         //
         self.0.seek_from_start(offset)?;
-        let record_size = self.0.read_record_size()?;
-        debug_assert!(record_size.is_valid_key());
+        let piece_size = self.0.read_piece_size()?;
+        debug_assert!(piece_size.is_valid_key());
         let key_len = self.0.read_key_len()?;
         let maybe = self.0.read_exact_maybeslice(key_len.into())?;
         let key = KT::from_bytes(&maybe);
         //
         #[cfg(feature = "htx")]
-        let val_offset = self.0.read_value_record_offset()?;
+        let val_offset = self.0.read_value_piece_offset()?;
         #[cfg(not(feature = "htx"))]
-        let val_offset = self.0.read_record_offset()?;
+        let val_offset = self.0.read_piece_offset()?;
         //
-        let record = KeyRecord::with(offset, record_size, key, val_offset);
+        let piece = KeyPiece::with(offset, piece_size, key, val_offset);
         //
-        Ok(record)
+        Ok(piece)
     }
 
     #[inline]
-    fn read_record_only_size(&mut self, offset: KeyRecordOffset) -> Result<KeyRecordSize> {
+    fn read_piece_only_size(&mut self, offset: KeyPieceOffset) -> Result<KeyPieceSize> {
         debug_assert!(!offset.is_zero());
         //
         self.0.seek_from_start(offset)?;
-        let record_size = self.0.read_record_size()?;
-        Ok(record_size)
+        let piece_size = self.0.read_piece_size()?;
+        Ok(piece_size)
     }
 
     #[inline]
-    fn read_record_only_key_length(&mut self, offset: KeyRecordOffset) -> Result<KeyLength> {
+    fn read_piece_only_key_length(&mut self, offset: KeyPieceOffset) -> Result<KeyLength> {
         debug_assert!(!offset.is_zero());
         //
-        self.0.seek_skip_to_record_key(offset)?;
+        self.0.seek_skip_to_piece_key(offset)?;
         let key_len = self.0.read_key_len()?;
         Ok(key_len)
     }
 
     #[inline]
-    pub fn read_record_only_key_maybeslice(
+    pub fn read_piece_only_key_maybeslice(
         &mut self,
-        offset: KeyRecordOffset,
+        offset: KeyPieceOffset,
     ) -> Result<rabuf::MaybeSlice> {
         debug_assert!(!offset.is_zero());
         //
-        self.0.seek_skip_to_record_key(offset)?;
+        self.0.seek_skip_to_piece_key(offset)?;
         let key_len = self.0.read_key_len()?;
         let maybe_slice = self.0.read_exact_maybeslice(key_len.into())?;
         Ok(maybe_slice)
     }
 
     #[inline]
-    fn read_record_only_key(&mut self, offset: KeyRecordOffset) -> Result<KT> {
+    fn read_piece_only_key(&mut self, offset: KeyPieceOffset) -> Result<KT> {
         debug_assert!(!offset.is_zero());
         //
-        self.0.seek_skip_to_record_key(offset)?;
+        self.0.seek_skip_to_piece_key(offset)?;
         let key_len = self.0.read_key_len()?;
         let maybe_slice = self.0.read_exact_maybeslice(key_len.into())?;
         Ok(KT::from_bytes(&maybe_slice))
     }
 
     #[inline]
-    fn read_record_only_value_offset(
-        &mut self,
-        offset: KeyRecordOffset,
-    ) -> Result<ValueRecordOffset> {
+    fn read_piece_only_value_offset(&mut self, offset: KeyPieceOffset) -> Result<ValuePieceOffset> {
         debug_assert!(!offset.is_zero());
         //
-        self.0.seek_skip_to_record_key(offset)?;
+        self.0.seek_skip_to_piece_key(offset)?;
         let key_len = self.0.read_key_len()?;
         self.0.seek_skip_length(key_len)?;
         //
         #[cfg(feature = "htx")]
-        let value_offset = self.0.read_value_record_offset()?;
+        let value_offset = self.0.read_value_piece_offset()?;
         #[cfg(not(feature = "htx"))]
-        let value_offset = self.0.read_record_offset()?;
+        let value_offset = self.0.read_piece_offset()?;
         Ok(value_offset)
     }
 }
@@ -545,7 +524,7 @@ used piece:
 | 0      | 1..5  | piece size  | size in bytes of this piece: u32  |
 | --     | 1..5  | key len     | a byte length of key              |
 | --     | --    | key data    | raw key data                      |
-| --     | 8     | val offset  | value record offset: u64          |
+| --     | 8     | val offset  | value piece offset: u64          |
 | --     | --    | reserve     | reserved free space               |
 +--------+-------+-------------+-----------------------------------+
 ```
@@ -558,7 +537,7 @@ free piece:
 +--------+-------+-------------+-----------------------------------+
 | 0      | 1..5  | piece size  | size in bytes of this piece: u32  |
 | --     | 1     | key len     | always zero                       |
-| --     | 8     | next        | next free record offset           |
+| --     | 8     | next        | next free piece offset           |
 | --     | --    | reserve     | reserved free space               |
 +--------+-------+-------------+-----------------------------------+
 ```
