@@ -39,7 +39,7 @@ fn test01(db_name: &str, data: &[(String, String)]) -> std::io::Result<()> {
     //
     for (k, v) in data {
         eprintln!("k:'{}', v:'{}'", k, v);
-        db_map.put_string(k.into(), v.as_str()).unwrap();
+        db_map.put_string(k, v.as_str()).unwrap();
     }
     //
     db_map.sync_data().unwrap();
@@ -67,16 +67,16 @@ fn _print_check_db_map(db_map: &FileDbMapDbString, check_cnf: CheckC) {
         println!("{}", db_map.graph_string_with_key_string().unwrap());
     }
     println!(
-        "key record free: {:?}",
-        db_map.count_of_free_key_record().unwrap()
+        "key piece free: {:?}",
+        db_map.count_of_free_key_piece().unwrap()
     );
     let (key_rec_v, val_rec_v, node_v) = db_map.count_of_used_node().unwrap();
-    println!("key record used: {:?}", key_rec_v);
+    println!("key piece used: {:?}", key_rec_v);
     println!(
-        "value record free: {:?}",
-        db_map.count_of_free_value_record().unwrap()
+        "value piece free: {:?}",
+        db_map.count_of_free_value_piece().unwrap()
     );
-    println!("value record used: {:?}", val_rec_v);
+    println!("value piece used: {:?}", val_rec_v);
     println!("node free: {:?}", db_map.count_of_free_node().unwrap());
     println!("node used: {:?}", node_v);
     println!("db_map.is_balanced(): {}", db_map.is_balanced().unwrap());
@@ -91,11 +91,11 @@ fn _print_check_db_map(db_map: &FileDbMapDbString, check_cnf: CheckC) {
     #[cfg(feature = "buf_stats")]
     println!("db_map.buf_stats(): {:?}", db_map.buf_stats());
     println!(
-        "key_record_size_stats(): {}",
-        db_map.key_record_size_stats().unwrap()
+        "key_piece_size_stats(): {}",
+        db_map.key_piece_size_stats().unwrap()
     );
     println!(
-        "value_record_size_stats(): {}",
-        db_map.value_record_size_stats().unwrap()
+        "value_piece_size_stats(): {}",
+        db_map.value_piece_size_stats().unwrap()
     );
 }
